% Function to estimate the pavement thickness 
% of a flexible pavement
%
% Input arguments: 
%
% load = single wheel equivalent load (pounds)
% area = tire contact area (in-in)
% cbr  = California bearing ratio (dimensionless)
%
% Output arguments
%
% t = pavement thickness

function t=thickness(load,area,cbr)

t = sqrt(load ./ (8.1 .* cbr) + area/pi);
